diff --git a/src/wp-admin/includes/class-plugin-installer-skin.php b/src/wp-admin/includes/class-plugin-installer-skin.php
index b8cf4b41db..65c0088d67 100644
--- a/src/wp-admin/includes/class-plugin-installer-skin.php
+++ b/src/wp-admin/includes/class-plugin-installer-skin.php
@@ -251,7 +251,7 @@ class Plugin_Installer_Skin extends WP_Upgrader_Skin {
* @param array $current_plugin_data Array with current plugin data.
* @param array $new_plugin_data Array with uploaded plugin data.
*/
- echo apply_filters( 'install_plugin_ovewrite_comparison', $table, $current_plugin_data, $new_plugin_data );
+ echo apply_filters( 'install_plugin_overwrite_comparison', $table, $current_plugin_data, $new_plugin_data );
$install_actions = array();
$can_update = true;
@@ -307,7 +307,7 @@ class Plugin_Installer_Skin extends WP_Upgrader_Skin {
$overwrite = $this->is_downgrading ? 'downgrade-plugin' : 'update-plugin';
- $install_actions['ovewrite_plugin'] = sprintf(
+ $install_actions['overwrite_plugin'] = sprintf(
'%s',
wp_nonce_url( add_query_arg( 'overwrite', $overwrite, $this->url ), 'plugin-upload' ),
__( 'Replace current with uploaded' )
@@ -325,7 +325,7 @@ class Plugin_Installer_Skin extends WP_Upgrader_Skin {
);
/**
* Filters the list of action links available following a single plugin installation failed but ovewrite is allowed.
*
* @since 5.5.0
*
@@ -333,7 +333,7 @@ class Plugin_Installer_Skin extends WP_Upgrader_Skin {
* @param object $api Object containing WordPress.org API plugin data.
* @param array $new_plugin_data Array with uploaded plugin data.
*/
- $install_actions = apply_filters( 'install_plugin_ovewrite_actions', $install_actions, $this->api, $new_plugin_data );
+ $install_actions = apply_filters( 'install_plugin_overwrite_actions', $install_actions, $this->api, $new_plugin_data );
if ( ! empty( $install_actions ) ) {
printf(
@@ -325,7 +325,7 @@ class Plugin_Installer_Skin extends WP_Upgrader_Skin {
);
/**
- * Filters the list of action links available following a single plugin installation failed but ovewrite is allowed.
+ * Filters the list of action links available following a single plugin installation failed but overwrite is allowed.
*
* @since 5.5.0
diff --git a/src/wp-admin/includes/class-theme-installer-skin.php b/src/wp-admin/includes/class-theme-installer-skin.php
index cd6145a978..9d93bcfadf 100644
--- a/src/wp-admin/includes/class-theme-installer-skin.php
+++ b/src/wp-admin/includes/class-theme-installer-skin.php
@@ -340,7 +340,7 @@ class Theme_Installer_Skin extends WP_Upgrader_Skin {
$overwrite = $this->is_downgrading ? 'downgrade-theme' : 'update-theme';
- $install_actions['ovewrite_theme'] = sprintf(
+ $install_actions['overwrite_theme'] = sprintf(
'%s',
wp_nonce_url( add_query_arg( 'overwrite', $overwrite, $this->url ), 'theme-upload' ),
__( 'Replace current with uploaded' )
@@ -358,7 +358,7 @@ class Theme_Installer_Skin extends WP_Upgrader_Skin {
);
/**
* Filters the list of action links available following a single theme installation failed but ovewrite is allowed.
*
* @since 5.5.0
*
@@ -366,7 +366,7 @@ class Theme_Installer_Skin extends WP_Upgrader_Skin {
* @param object $api Object containing WordPress.org API theme data.
* @param array $new_theme_data Array with uploaded theme data.
*/
- $install_actions = apply_filters( 'install_theme_ovewrite_actions', $install_actions, $this->api, $new_theme_data );
+ $install_actions = apply_filters( 'install_theme_overwrite_actions', $install_actions, $this->api, $new_theme_data );
if ( ! empty( $install_actions ) ) {
printf(
@@ -358,7 +358,7 @@ class Theme_Installer_Skin extends WP_Upgrader_Skin {
);
/**
- * Filters the list of action links available following a single theme installation failed but ovewrite is allowed.
+ * Filters the list of action links available following a single theme installation failed but overwrite is allowed.
*
* @since 5.5.0